@@ -65,3 +65,6 @@ pub use phases::*;
 
 pub mod option;
 pub use option::*;
+
+#[cfg(test)]
+mod test;
